@@ -1,5 +1,5 @@
 # other.py | misc. commands
-# Copyright (C) 2019-2020  EraserBird, person_v1.32, hmmm
+# Copyright (C) 2019-2021  EraserBird, person_v1.32, hmmm
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,11 +26,26 @@ from sciolyid.core import send_image
 from sciolyid.data import aliases, groups, logger, master_id_list, meme_list
 from sciolyid.functions import CustomCooldown, build_id_list
 
+# Discord max message length is 2000 characters, leave some room just in case
+MAX_MESSAGE = 1950
 
 class Other(commands.Cog):
     def __init__(self, bot):
         self.bot = bot
 
+    @staticmethod
+    def broken_join(input_list, max_size: int = MAX_MESSAGE):
+        out = []
+        temp = ""
+        for item in input_list:
+            temp += f"{item}\n"
+            if len(temp) > max_size:
+                out.append(temp)
+                temp = ""
+        if temp:
+            out.append(temp)
+        return out
+
     # Info - Gives image
     @commands.command(
         help=f"- Gives images of specific {config.options['id_type']}", aliases=["i"]
@@ -43,7 +58,7 @@ class Other(commands.Cog):
             arg.lower(),
             master_id_list + list(itertools.chain.from_iterable(aliases.values())),
             n=1,
-            cutoff=0.8
+            cutoff=0.8,
         )
         if matches:
             item = matches[0]
@@ -53,7 +68,7 @@ class Other(commands.Cog):
                 item = next(key for key, value in aliases.items() if item in value)
 
             delete = await ctx.send("Please wait a moment.")
-            an = "an" if item.lower()[0] in ('a', 'e', 'i', 'o', 'u') else 'a'
+            an = "an" if item.lower()[0] in ("a", "e", "i", "o", "u") else "a"
             await send_image(
                 ctx, str(item), message=f"Here's {an} *{item.lower()}* image!"
             )
@@ -74,14 +89,7 @@ class Other(commands.Cog):
         group_list = build[0]
         detected_groups = "total items" if build[1] == "None" else build[1]
 
-        item_lists = []
-        temp = ""
-        for item in group_list:
-            temp += f"{item}\n"
-            if len(temp) > 1950:
-                item_lists.append(temp)
-                temp = ""
-        item_lists.append(temp)
+        item_lists = self.broken_join(group_list)
 
         if ctx.author.dm_channel is None:
             await ctx.author.create_dm()
@@ -137,7 +145,9 @@ class Other(commands.Cog):
         @commands.command(
             help=f"- Sends a funny {config.options['id_type'][:-1]} video/image!"
         )
-        @commands.check(CustomCooldown(180.0, disable=True, bucket=commands.BucketType.user))
+        @commands.check(
+            CustomCooldown(180.0, disable=True, bucket=commands.BucketType.user)
+        )
         async def meme(self, ctx):
             logger.info("command: meme")
 
@@ -150,19 +160,13 @@ class Other(commands.Cog):
         # Send command - for testing purposes only
         @commands.command(help="- send command", hidden=True, aliases=["sendas"])
         @commands.is_owner()
-        async def send_as_bot(self, ctx, *, args_str):
+        async def send_as_bot(self, ctx, channel_id: int, message):
             logger.info("command: send")
 
-            logger.info(f"args: {args_str}")
-            args = args_str.split(" ")
+            logger.info(f"args: {channel_id}, {message}")
 
-            channel_id = int(args[0])
-            try:
-                message = args[1:]
-            except IndexError:
-                await ctx.send("No message provided!")
             channel = self.bot.get_channel(channel_id)
-            await channel.send(" ".join(message))
+            await channel.send(message)
             await ctx.send("Ok, sent!")
 
     # # Test command - for testing purposes only
