@@ -1,5 +1,5 @@
 # score.py | commands to show score related things
-# Copyright (C) 2019-2020  EraserBird, person_v1.32, hmmm
+# Copyright (C) 2019-2021  EraserBird, person_v1.32, hmmm
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@ import typing
 import discord
 import pandas as pd
 from discord.ext import commands
+from discord.utils import escape_markdown as esc
 
 import sciolyid.config as config
 from sciolyid.data import GenericError, database, logger
@@ -125,9 +126,9 @@ class Score(commands.Cog):
                 if user is None:
                     user_info = "**Deleted**"
                 else:
-                    user_info = f"**{user.name}#{user.discriminator}**"
+                    user_info = f"**{esc(user.name)}#{user.discriminator}**"
             else:
-                user_info = f"**{user.name}#{user.discriminator}** ({user.mention})"
+                user_info = f"**{esc(user.name)}#{user.discriminator}** ({user.mention})"
 
             leaderboard += f"{i+1+page}. {user_info} - {int(stats[1])}\n"
 
