@@ -1,5 +1,5 @@
 # stats.py | commands for bot statistics
-# Copyright (C) 2019-2020  EraserBird, person_v1.32, hmmm
+# Copyright (C) 2019-2021  EraserBird, person_v1.32, hmmm
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -273,7 +273,7 @@ class Stats(commands.Cog):
                 data = await self.convert_users(data)
             with StringIO() as f:
                 f.write(header)
-                data.to_csv(f, mode="wb", header=False)
+                data.to_csv(f, header=False)
                 with BytesIO(f.getvalue().encode("utf-8")) as b:
                     files.append(discord.File(b, filename))
 
