@@ -1,5 +1,5 @@
 # start_bot.py | main program
-# Copyright (C) 2019-2020  EraserBird, person_v1.32, hmmm
+# Copyright (C) 2019-2021  EraserBird, person_v1.32, hmmm
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,8 +30,14 @@ from sentry_sdk import capture_exception
 
 import sciolyid.config as config
 from sciolyid.data import GenericError, database, logger
-from sciolyid.functions import (backup_all, channel_setup, fools,
-                                get_all_users, user_setup)
+from sciolyid.functions import (
+    backup_all,
+    channel_setup,
+    fools,
+    get_all_users,
+    prune_user_cache,
+    user_setup,
+)
 
 # Initialize bot
 intent: discord.Intents = discord.Intents.none()
@@ -69,6 +75,7 @@ async def on_ready():
     # start tasks
     update_images.start()
     refresh_user_cache.start()
+    evict_user_cache.start()
     if config.options["backups_channel"]:
         refresh_backup.start()
 
@@ -363,14 +370,21 @@ async def update_images():
     logger.info("done updating images!")
 
 
-@tasks.loop(hours=12.0)
+@tasks.loop(hours=3.0)
 async def refresh_user_cache():
     """Task to update User cache to increase performance of commands."""
     logger.info("TASK: Updating User cache")
     await get_all_users(bot)
 
 
-@tasks.loop(hours=6.0)
+@tasks.loop(minutes=8.0)
+async def evict_user_cache():
+    """Task to remove keys from the User cache to ensure freshness."""
+    logger.info("TASK: Removing user keys")
+    await prune_user_cache(10)
+
+
+@tasks.loop(hours=1.0)
 async def refresh_backup():
     """Sends a copy of the database to a discord channel (BACKUPS_CHANNEL)."""
     logger.info("Refreshing backup")
